<?php
/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Company Account Hyva
 */

declare(strict_types=1);

namespace Amasty\CompanyAccountHyva\ViewModel;

use Magento\Framework\View\Element\Block\ArgumentInterface;
use Magento\Framework\Serialize\SerializerInterface;
use Magento\Directory\Model\Country\Postcode\Config as PostCodeConfig;
use Magento\Directory\Helper\Data as DirectoryHelper;

class CompanyAccount implements ArgumentInterface
{
    /**
     * @var PostCodeConfig
     */
    private $postCodeConfig;

    /**
     * @var SerializerInterface
     */
    private $serializer;

    /**
     * @var DirectoryHelper
     */
    private $directoryHelper;

    /**
     * Constructor
     *
     * @param PostCodeConfig $postCodeConfig
     * @param SerializerInterface $serializer
     * @param DirectoryHelper $directoryHelper
     */
    public function __construct(
        PostCodeConfig $postCodeConfig,
        SerializerInterface $serializer,
        DirectoryHelper $directoryHelper
    ) {
        $this->postCodeConfig = $postCodeConfig;
        $this->serializer = $serializer;
        $this->directoryHelper = $directoryHelper;
    }

    /**
     * Get serialized post codes
     *
     * @return string
     */
    public function getSerializedPostCodes(): string
    {
        return $this->serializer->serialize($this->postCodeConfig->getPostCodes());
    }

    /**
     * Get required countries
     *
     * @return array
     */
    public function getCountriesWithStatesRequired(): array
    {
        return $this->directoryHelper->getCountriesWithStatesRequired();
    }
}
